function P=calcul_poly_symb_unsursqrt(n)

%	calcul_poly_symb_unsursqrt : calcul de polynmes orthogonal (rcurrence)
%
% *********************************************************
%
% P=calcul_poly_symb_unsursqrt(n) renvoie les polynmes de Gauss P_0,P_1,...,P_n
%   pour les poids w(x)=1/sqrt(1-x) calcul par rcurrence et en symbolique.
%   avec la condition de normalisation : P_n(0)=1.
%
%	variables d'entres : 
%    *  n : entier naturel.
%	variables de sortie
%     * P : tableau de taille (n+1)*(n+1) tel que 
%           pour tout i dans {1,...,n+1}, L(i,1:i) contient
%           le polynme L_{i-1} (coefficient dominant en tte)
%            coefficients symboliques
% 
% 
% ************ Fonctions auxiliaires utilises ************
%
%  calculintegralexn_unsursqrt, multiplie_poly_symb
%
% *********************************************************
%


% Contrles d'entre
% nombre d'arguments
if nargin~=1
   error('nombre d''arguments de la fonction incorrect');
end
% autres tests ventuels 
if (fix(n)~=n) | (n<0)
   error('l''entier n doit tre un entier naturel');
end

% Corps d'algorithme.
P=zeros(n+1,n+1);
P=sym(P);
P(1,1)=1;
Lb=[];
La=[1];
Ck=sym(1);
if (n>=1)
   calculintegralexnmaxi=calculintegralexn_unsursqrt(2*n-1);
   for k=0:n-1      
       if (k==0)
          Sk=sym(2);    
          Bk=calculintegralexnmaxi(2)/Sk;
          Ck=sym(1);
       else    
          Sknew=sum(multiplie_poly_symb(La,La).*fliplr(calculintegralexnmaxi(1:2*k+1)));
          Bk=sum(multiplie_poly_symb(La,[La sym(0)]).*fliplr(calculintegralexnmaxi(1:2*k+2)))/Sknew;
          Ck=Sknew/Sk;
          Sk=Sknew;
       end
       Lc=multiplie_poly_symb([sym(1) -Bk],La)-[sym(0) sym(0) Ck*Lb];
       Lb=La;
       La=Lc;
       P(k+2,1:k+2)=Lc/Lc(end);    
   end
end