function [points,poids]=points_poids_gauss_wpoids(a,b,w,n)

% REFAIRE COMMENTAIRE
%
% points_poids_gauss_wpoids : calcul des poids et des points de Gauss pour un poids et un intervalle quelconque
%  
%  *********************************************************
% 
%  [points,poids]=(a,b,w,n) renvoie les points x_i et les poids W_i
%   		  des formules d'intgration  l+1 points pour 0<=l<=n, pour 
%             une mthode de quadrature quelconque, en symbolique,
%             puis par diagonalisation d'une matrice tridiagonale.
% 
%	variables d'entres : 
%     
%     *  a,b : bornes de l'intervalle,
%     *  w : poids (en inline ou fichier)
%     *  n : entier naturel
%
% 	variables de sortie
%      * points : tableau de taille (n+1)*(n+1) tel que 
%                 pour tout l dans {0,...,n}, points(l+1,1:l+1) contient
%                 les l+1 points x_i de la formule ( l+1 points)
%     * poids  : tableau de taille (n+1)*(n+1) tel que 
%                 pour tout l dans {0,...,n}, poids(l+1,1:l+1) contient
%                 les l+1 poids D_i de la formule ( l+1 points)
% 
% 
%  ************ Fonctions auxiliaires utilises ************
% 
%   calcul_poly_gauss
% 
%  *********************************************************


% calcul des I_n=int(x^n*w(x));
syms x;
f=feval(w,x);
for k=0:2*n+1
    calculintegralexnmaxi(k+1)=int(f*x^k,x,sym(a),sym(b)); 
end

% Corps d'algorithme : calcul des C_i pour i dans {1,...,n}
% et B_i pour i dans {0,...,n}, en passant par les diffrents polynmes.
Lb=[];
La=[1];
Ck=sym(1);
B=sym(zeros(1,n+1));
C=sym(zeros(1,n));
if (n>=1)
   for k=0:n-1      
       if (k==0)
          Sk=calculintegralexnmaxi(1);    
          Bk=calculintegralexnmaxi(2)/Sk;
          Ck=sym(1);
          B(1)=Bk;
      else    
          Sknew=sum(multiplie_poly_symb(La,La).*fliplr(calculintegralexnmaxi(1:2*k+1)));
          Bk=sum(multiplie_poly_symb(La,[La sym(0)]).*fliplr(calculintegralexnmaxi(1:2*k+2)))/Sknew;
          Ck=Sknew/Sk;
          Sk=Sknew;
          B(k+1)=Bk;
          C(k)=Ck;          
      end
      Lc=multiplie_poly_symb([sym(1) -Bk],La)-[sym(0) sym(0) Ck*Lb];
      Lb=La;
      La=Lc;
   end
   Sknew=sum(multiplie_poly_symb(La,La).*fliplr(calculintegralexnmaxi(1:2*n+1)));
   Bk=sum(multiplie_poly_symb(La,[La sym(0)]).*fliplr(calculintegralexnmaxi(1:2*n+2)))/Sknew;
   Ck=Sknew/Sk;
   Sk=Sknew;
   B(n+1)=Bk;
   C(n)=Ck;          
end

% calcul de la matrice tridiagonale  partir de B et dec C
if (n>=1)
   gamma=sqrt(double(C));
   B=double(B);
end

% calcul des poids et points par diagonalisation :
points=zeros(n+1,n+1);
poids=zeros(n+1,n+1);
points(1,1)=calculintegralexnmaxi(2)/calculintegralexnmaxi(1);
poids(1,1)=calculintegralexnmaxi(1);
for k=1:n
   auxi=gallery('tridiag',gamma(1:k),B(1:k+1),gamma(1:k));
   if (k<=4) 
      [Q,R]=eigs(auxi,k+1);
   else
      [Q,R]=eig(full(auxi));
   end
   R=diag(R);
   U=(sqrt(sum(Q.^2)));
   auxik=calculintegralexnmaxi(1);     
   Q=auxik*(Q(1,:)./U).^2;
   [auxipoints,ind]=sort((flipud(R))');
   auxi=fliplr(Q);
   auxipoids=auxi(ind);
   points(k+1,1:k+1)=auxipoints;
   poids(k+1,1:k+1)=auxipoids;
end
    










