function [points,poids]=points_poids_unsursqrt(n)

% points_poids_unsursqrt : calcul des poids et des points de Gauss pour w(x)=1/sqrt(1-x); 
% 
% *********************************************************
%
% [points,poids]=points_poids_unsursqrt(n) renvoie les points W_i et les points x_i
%   				  des formules d'intgration  l+1 points pour 0<=l<=n, pour 
%                     le poids w(x)=1/sqrt(1-x);
%
%	variables d'entres : 
%    *  n : entier naturel.
%
%	variables de sortie
%     * points : tableau de taille (n+1)*(n+1) tel que 
%                pour tout l dans {0,...,n}, points(l+1,1:l+1) contient
%                les l+1 points x_i de la formule ( l+1 points)
%     * poids  : tableau de taille (n+1)*(n+1) tel que 
%                pour tout l dans {0,...,n}, poids(l+1,1:l+1) contient
%                les l+1 poids D_i de la formule ( l+1 points)
%
% 
% 
% ************ Fonctions auxiliaires utilises ************
%
%    points_poids_gauss_diago
%
% *********************************************************


% Contrles d'entre
% nombre d'arguments
if nargin~=1
   error('nombre d''arguments de la fonction incorrect');
end
% autres tests ventuels 
if (fix(n)~=n) | (n<0)
   error('l''entier n doit tre un entier naturel');
end

% Corps d'algorithme.
[A,B]=points_poids_gauss_diago(1,2*n+1);
auxipoints=A(2:2:2*n+2,:);
auxipoids=B(2:2:2*n+2,:);
points=zeros(n+1,n+1);
poids=zeros(n+1,n+1);
for i=0:n
    p=i+2;
    points(i+1,:)=1-(auxipoints(i+1,p:p+n)).^2;
    ind=find(points==1);
    points(ind)=0;
    poids(i+1,:)=2*auxipoids(i+1,p:p+n);
end
